@@ -1,20 +1,15 @@
-from unittest.mock import create_autospec
-
 import pytest
 
-import smarttub
 from smarttub import SpaPump
 
 pytestmark = pytest.mark.asyncio
 
 
 @pytest.fixture
-def pumps(mock_api):
-    spa = create_autospec(smarttub.Spa, instance=True)
-    spa.request = mock_api.request
+def pumps(mock_spa):
     pumps = [
         SpaPump(
-            spa,
+            mock_spa,
             **{
                 "id": "pid1",
                 "speed": "speed1",
@@ -22,12 +17,18 @@ def pumps(mock_api):
                 if pump_type == SpaPump.PumpType.CIRCULATION
                 else SpaPump.PumpState.HIGH.name,
                 "type": pump_type.name,
-            }
+            },
         )
         for i, pump_type in enumerate(SpaPump.PumpType)
     ]
     return pumps
 
 
-async def test_pump(pumps):
-    pass
+async def test_pump(mock_spa, pumps):
+    circ = pumps[1]
+    assert str(circ)
+    assert circ.speed == "speed1"
+    assert circ.state == SpaPump.PumpState.OFF
+    assert circ.type == SpaPump.PumpType.CIRCULATION
+    await circ.toggle()
+    mock_spa.request.assert_called_with("POST", f"pumps/{circ.id}/toggle")
